(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     49110,       1170]
NotebookOptionsPosition[     48333,       1140]
NotebookOutlinePosition[     48679,       1155]
CellTagsIndexPosition[     48636,       1152]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Code", "Section",
 CellChangeTimes->{{3.560770373307825*^9, 3.5607703746178265`*^9}}],

Cell[TextData[{
 "This code is based on a ",
 ButtonBox["Demonstration",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/CollidingGalaxies/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/CollidingGalaxies/"],
 " that uses point clouds. The primary difference is that the drawing code \
(see the Draw function) bins the points into 3D cobes and turns them into \
voxels."
}], "Text",
 CellChangeTimes->{{3.5607703787878323`*^9, 3.5607703797678337`*^9}, {
   3.560770415725381*^9, 3.5607704810374722`*^9}, {3.5607705746226034`*^9, 
   3.560770584002617*^9}, 3.5607706310246825`*^9}],

Cell["\<\
*NOTE* evaluating this code sets the working directory to the notebooks \
directory and exports the frames to that directory. Make sure you have this \
notebook saved into an acceptable location.\
\>", "Text",
 CellChangeTimes->{{3.560770489278484*^9, 3.5607705533805733`*^9}}],

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"t", "\[Equal]", "0"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "Dist", ",", "MF", ",", "V1", ",", "V2", ",", "ss", ",", "tcol", ",", 
         "icol", ",", "vp", ",", "TIME", ",", "M2", ",", "pos", ",", "pos2", 
         ",", "XX1", ",", "XX2", ",", "vel", ",", "vel2"}], "}"}], "=", 
       RowBox[{"Initialize", "[", 
        RowBox[{"Dist", ",", "MF", ",", "XX1", ",", 
         RowBox[{"{", 
          RowBox[{"iposx", ",", "iposy", ",", "iposz"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"iposx", ",", "iposy", ",", "iposz"}], "}"}], ",", "pos2", 
         ",", "vel", ",", 
         RowBox[{"{", 
          RowBox[{"ivelx", ",", "ively", ",", "ivelz"}], "}"}], ",", "V1", 
         ",", 
         RowBox[{"{", 
          RowBox[{"ivelx", ",", "ively", ",", "ivelz"}], "}"}], ",", "ss", 
         ",", "tcol", ",", "icol", ",", "vp", ",", "TIME", ",", "ir", ",", 
         "tr", ",", "sep"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Draw", "[", 
       RowBox[{
       "XX1", ",", "XX2", ",", "MF", ",", "pos", ",", "pos2", ",", "Dist", 
        ",", "TIME", ",", "vp", ",", ".005", ",", "tcol", ",", "icol"}], 
       "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Do", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "pos", ",", "pos2", ",", "vel", ",", "vel2", ",", "XX1", ",", "XX2",
            ",", "V1", ",", "V2", ",", "TIME"}], "}"}], "=", 
         RowBox[{"Iterate", "[", 
          RowBox[{
          "XX1", ",", "XX2", ",", "M2", ",", "pos", ",", "pos2", ",", "vel", 
           ",", "vel2", ",", "V1", ",", "V2", ",", "TIME"}], "]"}]}], ",", 
        RowBox[{"{", "step", "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Draw", "[", 
       RowBox[{
       "XX1", ",", "XX2", ",", "MF", ",", "pos", ",", "pos2", ",", "Dist", 
        ",", "TIME", ",", "vp", ",", ".005", ",", "tcol", ",", "icol"}], 
       "]"}]}]}], "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"tr", ",", "30", ",", "\"\<target radius\>\""}], "}"}], ",", 
     "20", ",", "100", ",", "1", ",", 
     RowBox[{"ControlPlacement", "\[Rule]", "Top"}], ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ir", ",", "10", ",", "\"\<intruder radius\>\""}], "}"}], ",", 
     "10", ",", "100", ",", "1", ",", 
     RowBox[{"ControlPlacement", "\[Rule]", "Top"}], ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"sep", ",", ".1", ",", "\"\<star separation\>\""}], "}"}], ",", 
     ".1", ",", "7", ",", "1", ",", 
     RowBox[{"ControlPlacement", "\[Rule]", "Top"}], ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"step", ",", "1", ",", "\"\<step size\>\""}], "}"}], ",", "1", 
     ",", "50", ",", 
     RowBox[{"ImageSize", "\[Rule]", "Tiny"}], ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"MF", ",", ".1", ",", "\"\<mass fraction\>\""}], "}"}], ",", 
     ".1", ",", "1", ",", 
     RowBox[{"ImageSize", "\[Rule]", "Tiny"}], ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", "Delimiter", ",", "\[IndentingNewLine]", 
   RowBox[{"Style", "[", 
    RowBox[{"\"\<intruder initial position\>\"", ",", "Bold"}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"iposx", ",", 
       RowBox[{"-", "50"}], ",", "\"\<x\>\""}], "}"}], ",", 
     RowBox[{"-", "50"}], ",", "50", ",", ".01", ",", 
     RowBox[{"ControlPlacement", "\[Rule]", "Left"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Tiny"}], ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"iposy", ",", 
       RowBox[{"-", "10"}], ",", "\"\<y\>\""}], "}"}], ",", 
     RowBox[{"-", "50"}], ",", "50", ",", ".01", ",", 
     RowBox[{"ControlPlacement", "\[Rule]", "Left"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Tiny"}], ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"iposz", ",", "0", ",", "\"\<z\>\""}], "}"}], ",", 
     RowBox[{"-", "50"}], ",", "50", ",", ".01", ",", 
     RowBox[{"ControlPlacement", "\[Rule]", "Left"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Tiny"}], ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", "Delimiter", ",", "\[IndentingNewLine]", 
   RowBox[{"Style", "[", 
    RowBox[{"\"\<intruder initial velocity\>\"", ",", "Bold"}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ivelx", ",", ".33", ",", "\"\<x\>\""}], "}"}], ",", 
     RowBox[{"-", "1"}], ",", "1", ",", ".01", ",", 
     RowBox[{"ControlPlacement", "\[Rule]", "Left"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Tiny"}], ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ively", ",", "0", ",", "\"\<y\>\""}], "}"}], ",", 
     RowBox[{"-", "1"}], ",", "1", ",", ".01", ",", 
     RowBox[{"ControlPlacement", "\[Rule]", "Left"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Tiny"}], ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ivelz", ",", "0", ",", "\"\<z\>\""}], "}"}], ",", 
     RowBox[{"-", "1"}], ",", "1", ",", ".01", ",", 
     RowBox[{"ControlPlacement", "\[Rule]", "Left"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Tiny"}], ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", "Delimiter", ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"reinit", ",", "False", ",", "\"\<\>\""}], "}"}], ",", 
     RowBox[{
      RowBox[{"Button", "[", 
       RowBox[{"\"\<reinitialize\>\"", ",", 
        RowBox[{"t", "=", "0"}]}], "]"}], "&"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "\"\<progress\>\""}], "}"}], ",", "0", ",", 
     "Infinity", ",", 
     RowBox[{"ControlType", "\[Rule]", "Trigger"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pos", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"vel", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pos2", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "50"}], ",", "50", ",", "50"}], "}"}]}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"vel2", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"XX1", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"XX2", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "50"}], ",", "50", ",", "50"}], "}"}]}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"M2", ",", ".1"}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"V1", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"V2", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"TIME", ",", "0"}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Dist", ",", "100"}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ss", ",", ".001"}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"tcol", ",", "Green"}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"icol", ",", "Cyan"}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"vp", ",", 
       RowBox[{"{", 
        RowBox[{"1.3", ",", 
         RowBox[{"-", "2.4"}], ",", "2."}], "}"}]}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   RowBox[{"AutorunSequencing", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[RuleDelayed]", 
    RowBox[{"{", 
     RowBox[{
     "tr", ",", "ir", ",", "sep", ",", "step", ",", "reinit", ",", "t", ",", 
      "MF", ",", "iposx", ",", "iposy", ",", "iposz", ",", "ivelx", ",", 
      "ively", ",", "ivelz"}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"ControlPlacement", "\[Rule]", "Left"}], ",", 
   RowBox[{"SynchronousUpdating", "\[Rule]", "False"}], ",", 
   RowBox[{"SynchronousInitialization", "\[Rule]", "False"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Initialization", "\[RuleDelayed]", 
    RowBox[{"(", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"SetDirectory", "[", 
       RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"M1", "=", "5"}], ";", "\[IndentingNewLine]", 
      RowBox[{"MinRad", "=", "5"}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "return", " ", "the", " ", "positions", " ", "and", " ", "velocities", 
        " ", "of", " ", "the", " ", "particles"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"posandvel", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"a_", ",", "b_", ",", "c_"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"r_", ",", "dr_"}], "}"}], ",", "m_"}], "]"}], ":=", 
       "\[IndentingNewLine]", 
       RowBox[{"Module", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "xp", ",", "yp", ",", "pos", ",", "unitvel", ",", "vel", ",", 
           "xandy"}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"xp", ",", "yp"}], "}"}], "=", 
           RowBox[{"norms", "[", 
            RowBox[{"{", 
             RowBox[{"a", ",", "b", ",", "c"}], "}"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"xandy", "=", 
           RowBox[{"Select", "[", 
            RowBox[{
             RowBox[{"Flatten", "[", 
              RowBox[{
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"x", ",", "y"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"x", ",", 
                   RowBox[{"-", "r"}], ",", "r", ",", "dr"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"y", ",", 
                   RowBox[{"-", "r"}], ",", "r", ",", "dr"}], "}"}]}], "]"}], 
               ",", "1"}], "]"}], ",", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"MinRad", "^", "2"}], "<", 
                RowBox[{"(", 
                 RowBox[{"#", ".", "#"}], ")"}], "<", 
                RowBox[{"r", "^", "2"}]}], ")"}], "&"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"pos", "=", 
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"xp", " ", 
                 RowBox[{"#", "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}], "+", 
                RowBox[{"yp", " ", 
                 RowBox[{"#", "[", 
                  RowBox[{"[", "2", "]"}], "]"}]}]}], ")"}], "&"}], ",", 
             "xandy"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"unitvel", "=", 
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], " ", "yp"}], "+", 
                  RowBox[{
                   RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], " ", "xp"}]}], ")"}], "/", 
                RowBox[{"Sqrt", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "^", "2"}], "+", 
                  RowBox[{
                   RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "^", "2"}]}], "]"}]}], 
               ")"}], "&"}], ",", "xandy"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"vel", "=", 
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"#", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "*", 
               RowBox[{"Sqrt", "[", 
                RowBox[{"m", "/", 
                 RowBox[{"Sqrt", "[", 
                  RowBox[{
                   RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ".", 
                   RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], "]"}]}], "&"}],
              ",", 
             RowBox[{"Transpose", "[", 
              RowBox[{"{", 
               RowBox[{"unitvel", ",", "pos"}], "}"}], "]"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"pos", ",", "vel"}], "}"}]}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "calculate", " ", "the", " ", "normal", " ", "vectors", " ", "to", " ",
         "the", " ", "velocities"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"norms", "[", 
        RowBox[{"{", 
         RowBox[{"x_", ",", 
          RowBox[{"0", "|", "0."}], ",", 
          RowBox[{"0", "|", "0."}]}], "}"}], "]"}], ":=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"norms", "[", "v_List", "]"}], ":=", "\[IndentingNewLine]", 
       RowBox[{"Module", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "w", ",", "u", ",", "wy", ",", "wz", ",", "ux", ",", "uy", ",", 
           "uz"}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"w", "=", 
           RowBox[{"{", 
            RowBox[{"0", ",", "wy", ",", "wz"}], "}"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"u", "=", 
           RowBox[{"{", 
            RowBox[{"ux", ",", "uy", ",", "uz"}], "}"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"w", "=", 
           RowBox[{"w", "/.", 
            RowBox[{"First", "[", 
             RowBox[{"NSolve", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"w", ".", "v"}], "\[Equal]", "0"}], ",", 
                 RowBox[{
                  RowBox[{"w", ".", "w"}], "\[Equal]", "1"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"wy", ",", "wz"}], "}"}]}], "]"}], "]"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"u", "=", 
           RowBox[{"u", "/.", 
            RowBox[{"First", "[", 
             RowBox[{"NSolve", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"u", ".", "v"}], "\[Equal]", "0"}], ",", 
                 RowBox[{
                  RowBox[{"u", ".", "w"}], "\[Equal]", "0"}], ",", 
                 RowBox[{
                  RowBox[{"u", ".", "u"}], "\[Equal]", "1"}]}], "}"}], ",", 
               "u"}], "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"w", ",", "u"}], "}"}]}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"CenterOfMass", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"X1_", ",", "Y1_", ",", "Z1_"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"X2_", ",", "Y2_", ",", "Z2_"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"M1_", ",", "M2_"}], "}"}]}], "]"}], ":=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"M1", " ", "X1"}], "+", 
            RowBox[{"M2", " ", "X2"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"M1", "+", "M2"}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"M1", " ", "Y1"}], "+", 
            RowBox[{"M2", " ", "Y2"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"M1", "+", "M2"}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"M1", " ", "Z1"}], "+", 
            RowBox[{"M2", " ", "Z2"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"M1", "+", "M2"}], ")"}]}]}], "}"}]}], ";", 
      RowBox[{
       RowBox[{"Initialize", "[", 
        RowBox[{
        "Dist_", ",", "MF_", ",", "XX1_", ",", "XX2_", ",", "pos_", ",", 
         "pos2_", ",", "vel_", ",", "vel2_", ",", "V1_", ",", "V2_", ",", 
         "ss_", ",", "tcol_", ",", "icol_", ",", "vp_", ",", "TIME_", ",", 
         "ir_", ",", "tr_", ",", "sep_"}], "]"}], ":=", 
       RowBox[{"Module", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "Rad1", ",", "Rad2", ",", "dr", ",", "intpl", ",", "Distlocal", ",",
            "MFlocal", ",", "M2local", ",", "poslocal", ",", "pos2local", ",",
            "vellocal", ",", "vel2local", ",", "XX1local", ",", "XX2local", 
           ",", "V1local", ",", "V2local", ",", "sslocal", ",", "tcollocal", 
           ",", "icollocal", ",", "vplocal", ",", "TIMElocal"}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{
            "Distlocal", ",", "Rad1", ",", "Rad2", ",", "dr", ",", "MFlocal", 
             ",", "XX2local", ",", "V2local", ",", "intpl", ",", "sslocal", 
             ",", "tcollocal", ",", "icollocal", ",", "vplocal", ",", 
             "TIMElocal"}], "}"}], "=", 
           RowBox[{"{", 
            RowBox[{
            "100", ",", "tr", ",", "ir", ",", "sep", ",", "MF", ",", "XX2", 
             ",", "V2", ",", "Automatic", ",", ".001", ",", "Green", ",", 
             "Cyan", ",", 
             RowBox[{"{", 
              RowBox[{"1.3", ",", 
               RowBox[{"-", "2.4"}], ",", "2."}], "}"}], ",", "0"}], "}"}]}], 
          ";", "\[IndentingNewLine]", 
          RowBox[{"intpl", "=", "V2local"}], ";", "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"intpl", "===", "Automatic"}], ",", 
              RowBox[{"intpl", "=", "V2local"}]}], "]"}], ";"}], "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"XX1local", "=", 
           RowBox[{"V1local", "=", 
            RowBox[{"{", 
             RowBox[{"0.", ",", "0.", ",", "0."}], "}"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"M2local", "=", 
           RowBox[{"MFlocal", " ", "M1"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"poslocal", ",", "vellocal"}], "}"}], "=", 
           RowBox[{"posandvel", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"Rad1", ",", "dr"}], "}"}], ",", "M1"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"pos2local", ",", "vel2local"}], "}"}], "=", 
           RowBox[{"posandvel", "[", 
            RowBox[{"intpl", ",", 
             RowBox[{"{", 
              RowBox[{"Rad2", ",", "dr"}], "}"}], ",", "M2local"}], "]"}]}], 
          ";", "\[IndentingNewLine]", 
          RowBox[{"pos2local", "=", 
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"#", "+", "XX2"}], ")"}], "&"}], ",", "pos2local"}], 
            "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"vel2local", "=", 
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"#", "+", "V2"}], ")"}], "&"}], ",", "vel2local"}], 
            "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
           "Distlocal", ",", "MFlocal", ",", "V1local", ",", "V2local", ",", 
            "sslocal", ",", "tcollocal", ",", "icollocal", ",", "vplocal", 
            ",", "TIMElocal", ",", 
            RowBox[{"Sequence", "@@", 
             RowBox[{"Realign", "[", 
              RowBox[{
              "XX1local", ",", "XX2local", ",", "M2local", ",", "poslocal", 
               ",", "pos2local"}], "]"}]}], ",", "vellocal", ",", 
            "vel2local"}], "}"}]}]}], "\[IndentingNewLine]", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Draw", "[", 
        RowBox[{
        "XX1_", ",", "XX2_", ",", "MF_", ",", "pos_", ",", "pos2_", ",", 
         "Dist_", ",", "TIME_", ",", "vp_", ",", "ss_", ",", "tcol_", ",", 
         "icol_"}], "]"}], ":=", 
       RowBox[{"Module", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"cm", "=", 
            RowBox[{"CenterOfMass", "[", 
             RowBox[{"XX1", ",", "XX2", ",", 
              RowBox[{"{", 
               RowBox[{"M1", ",", 
                RowBox[{"M1", "*", "MF"}]}], "}"}]}], "]"}]}], ",", "pts", 
           ",", "bins", ",", "rng", ",", "gr", ",", "tmp"}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"pts", "=", 
           RowBox[{"Cases", "[", 
            RowBox[{
             RowBox[{"Join", "[", 
              RowBox[{"pos", ",", "pos2"}], "]"}], ",", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}], "/;", 
              RowBox[{
               RowBox[{"Sqrt", "[", 
                RowBox[{
                 RowBox[{"x", "^", "2"}], "+", 
                 RowBox[{"y", "^", "2"}], "+", 
                 RowBox[{"z", "^", "2"}]}], "]"}], "<=", "150"}]}]}], "]"}]}],
           ";", "\[IndentingNewLine]", 
          RowBox[{"bins", "=", 
           RowBox[{"BinCounts", "[", 
            RowBox[{"pts", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "100"}], ",", "100", ",", "1"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "100"}], ",", "100", ",", "1"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "100"}], ",", "100", ",", "1"}], "}"}]}], "]"}]}],
           ";", "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{
            RowBox[{"rng", "=", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Min", "[", "#", "]"}], ",", 
                 RowBox[{"Max", "[", "#", "]"}]}], "}"}], "&"}], "@", 
              RowBox[{"Flatten", "[", "bins", "]"}]}]}], ";"}], "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"gr", "=", 
           RowBox[{"Blur", "[", 
            RowBox[{
             RowBox[{"Image3D", "[", 
              RowBox[{"bins", 
               RowBox[{"(*", 
                RowBox[{"Rescale", "[", 
                 RowBox[{"bins", ",", "rng", ",", 
                  RowBox[{"{", 
                   RowBox[{"0", ",", "100"}], "}"}]}], "]"}], "*)"}], ",", 
               RowBox[{"ViewPoint", "\[Rule]", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"-", "0.9219914143635742"}], ",", 
                  "2.287309556158463", ",", "2.3169261589757353`"}], "}"}]}], 
               ",", 
               RowBox[{"ViewVertical", "\[Rule]", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"-", "0.33707267028412446`"}], ",", 
                  RowBox[{"-", "0.1945634754748827"}], ",", 
                  "0.9211552903602437"}], "}"}]}], ",", 
               RowBox[{
               "ColorFunction", "\[Rule]", "\"\<RainbowOpacity\>\""}]}], 
              "]"}], ",", "4"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"Export", "[", 
           RowBox[{
            RowBox[{"\"\<Frame\>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"PaddedForm", "[", 
               RowBox[{"TIME", ",", "4", ",", 
                RowBox[{"NumberPadding", "\[Rule]", "\"\<0\>\""}], ",", 
                RowBox[{"NumberSigns", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{"\"\<\>\"", ",", "\"\<\>\""}], "}"}]}]}], "]"}], 
              "]"}], "<>", "\"\<.png\>\""}], ",", 
            RowBox[{"Rasterize", "[", 
             RowBox[{"Show", "[", 
              RowBox[{"gr", ",", 
               RowBox[{"ImageSize", "\[Rule]", 
                RowBox[{"{", 
                 RowBox[{"1280", ",", "720"}], "}"}]}], ",", 
               RowBox[{"SphericalRegion", "\[Rule]", "True"}], ",", 
               RowBox[{"ViewAngle", "\[Rule]", 
                RowBox[{"\[Pi]", "/", "12"}]}], ",", 
               RowBox[{"ViewPoint", "\[Rule]", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"-", "0.9219914143635742"}], ",", 
                  "2.287309556158463", ",", "2.3169261589757353`"}], "}"}]}], 
               ",", 
               RowBox[{"ViewVertical", "\[Rule]", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"-", "0.33707267028412446`"}], ",", 
                  RowBox[{"-", "0.1945634754748827"}], ",", 
                  "0.9211552903602437"}], "}"}]}]}], "]"}], "]"}]}], "]"}], 
          ";", "\[IndentingNewLine]", "gr"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"update", " ", "the", " ", "center", " ", "of", " ", "mass"}], 
       " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Realign", "[", 
        RowBox[{"XX1_", ",", "XX2_", ",", "M2_", ",", "pos_", ",", "pos2_"}], 
        "]"}], ":=", "\[IndentingNewLine]", 
       RowBox[{"Module", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "cm", ",", "poslocal", ",", "pos2local", ",", "XX1local", ",", 
           "XX2local"}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"cm", "=", 
           RowBox[{"CenterOfMass", "[", 
            RowBox[{"XX1", ",", "XX2", ",", 
             RowBox[{"{", 
              RowBox[{"M1", ",", "M2"}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"poslocal", "=", 
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"#", "-", "cm"}], "&"}], ",", "pos"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"pos2local", "=", 
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"#", "-", "cm"}], "&"}], ",", "pos2"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"XX1local", "=", 
           RowBox[{"XX1", "-", "cm"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"XX2local", "=", 
           RowBox[{"XX2", "-", "cm"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
           "M2", ",", "poslocal", ",", "pos2local", ",", "XX1local", ",", 
            "XX2local"}], "}"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{
        "iterate", " ", "the", " ", "simulation", " ", "by", " ", "one", " ", 
         "time", " ", "step", " ", "per", " ", "call"}], ",", " ", 
        RowBox[{
        "assuming", " ", "Keplerian", " ", "orbits", " ", "about", " ", "the",
          " ", "galaxy", " ", "centers"}]}], " ", "*)"}], 
      RowBox[{
       RowBox[{"Iterate", "[", 
        RowBox[{
        "XX1_", ",", "XX2_", ",", "M2_", ",", "pos_", ",", "pos2_", ",", 
         "vel_", ",", "vel2_", ",", "V1_", ",", "V2_", ",", "TIME_"}], "]"}], 
       ":=", 
       RowBox[{"Module", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "a1", ",", "a2", ",", "acc", ",", "rr", ",", "ar1", ",", "ar2", ",",
            "poslocal", ",", "vellocal", ",", "pos2local", ",", "vel2local", 
           ",", "XX1local", ",", "XX2local", ",", "V1local", ",", "V2local", 
           ",", "TIMElocal"}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{"starts", " ", "in", " ", "target", " ", "galaxy"}], " ", 
          "*)"}], "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"poslocal", ",", "vellocal"}], "}"}], "=", 
           RowBox[{"newstars", "[", 
            RowBox[{
            "pos", ",", "vel", ",", "XX1", ",", "XX2", ",", "M1", ",", "M2"}],
             "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{"starts", " ", "in", " ", "intruder", " ", "galaxy"}], " ",
            "*)"}], "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"pos2local", ",", "vel2local"}], "}"}], "=", 
           RowBox[{"newstars", "[", 
            RowBox[{
            "pos2", ",", "vel2", ",", "XX1", ",", "XX2", ",", "M1", ",", 
             "M2"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{"two", " ", "galaxies"}], " ", "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"rr", "=", 
           RowBox[{"XX2", "-", "XX1"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"ar1", "=", 
           RowBox[{"M2", "*", 
            RowBox[{"rr", "/", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"rr", ".", "rr"}], ")"}], "^", 
              RowBox[{"(", 
               RowBox[{"3", "/", "2"}], ")"}]}]}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"ar2", "=", 
           RowBox[{
            RowBox[{"-", "M1"}], "*", 
            RowBox[{"rr", "/", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"rr", ".", "rr"}], ")"}], "^", 
              RowBox[{"(", 
               RowBox[{"3", "/", "2"}], ")"}]}]}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"XX1local", "=", 
           RowBox[{"XX1", "+", "V1", "+", 
            RowBox[{"ar1", "/", "2"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"XX2local", "=", 
           RowBox[{"XX2", "+", "V2", "+", 
            RowBox[{"ar2", "/", "2"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"V1local", "=", 
           RowBox[{"V1", "+", "ar1"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"V2local", "=", 
           RowBox[{"V2", "+", "ar2"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"TIMElocal", "=", 
           RowBox[{"TIME", "+", "1"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
           "poslocal", ",", "pos2local", ",", "vellocal", ",", "vel2local", 
            ",", "XX1local", ",", "XX2local", ",", "V1local", ",", "V2local", 
            ",", "TIMElocal"}], "}"}]}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"find", " ", "the", " ", "updated", " ", "positions"}], ",", 
        " ", "velocities", ",", " ", 
        RowBox[{
        "and", " ", "accelerations", " ", "for", " ", "all", " ", 
         "particles"}]}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"newstars", "[", 
        RowBox[{
        "pos_", ",", "vel_", ",", "XX1_", ",", "XX2_", ",", "M1_", ",", 
         "M2_"}], "]"}], ":=", "\[IndentingNewLine]", 
       RowBox[{"Module", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "r1", ",", "r2", ",", "a1", ",", "a2", ",", "acc", ",", "newpos", 
           ",", "newvel", ",", "delpos"}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"delpos", "=", 
           RowBox[{"Position", "[", 
            RowBox[{"pos", ",", 
             RowBox[{"XX1", "|", "XX2"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"newpos", "=", 
           RowBox[{"Delete", "[", 
            RowBox[{"pos", ",", "delpos"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"newvel", "=", 
           RowBox[{"Delete", "[", 
            RowBox[{"vel", ",", "delpos"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"r1", "=", 
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"#", "-", "XX1"}], ")"}], "&"}], ",", "newpos"}], 
            "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"r2", "=", 
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"#", "-", "XX2"}], ")"}], "&"}], ",", "newpos"}], 
            "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"a1", "=", 
           RowBox[{"-", 
            RowBox[{"Map", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"M1", "/", 
                 RowBox[{
                  RowBox[{"Dot", "[", 
                   RowBox[{"#", ",", "#"}], "]"}], "^", 
                  RowBox[{"(", 
                   RowBox[{"3", "/", "2"}], ")"}]}]}], "*", "#"}], "&"}], ",",
               "r1"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"a2", "=", 
           RowBox[{"-", 
            RowBox[{"Map", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"M2", "/", 
                 RowBox[{
                  RowBox[{"Dot", "[", 
                   RowBox[{"#", ",", "#"}], "]"}], "^", 
                  RowBox[{"(", 
                   RowBox[{"3", "/", "2"}], ")"}]}]}], "*", "#"}], "&"}], ",",
               "r2"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"acc", "=", 
           RowBox[{"a1", "+", "a2"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"newpos", "=", 
           RowBox[{"newpos", "+", "newvel", "+", 
            RowBox[{"acc", "/", "2"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"newvel", "=", 
           RowBox[{"newvel", "+", "acc"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"newpos", ",", "newvel"}], "}"}]}]}], "]"}]}], ";"}], 
     "\[IndentingNewLine]", ")"}]}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.35696210375764*^9, 3.392219959125*^9, {3.392220033203125*^9, 
   3.392220064078125*^9}, {3.39222015153125*^9, 3.392220157828125*^9}, {
   3.392220242625*^9, 3.392220260640625*^9}, {3.3922204380625*^9, 
   3.39222043878125*^9}, {3.3922221526875*^9, 3.392222159234375*^9}, {
   3.3922222314375*^9, 3.392222369140625*^9}, {3.392222458359375*^9, 
   3.392222524375*^9}, {3.392222594140625*^9, 3.39222259996875*^9}, {
   3.39222263834375*^9, 3.39222264759375*^9}, {3.392222751828125*^9, 
   3.392222890734375*^9}, {3.392222986234375*^9, 3.39222299128125*^9}, {
   3.39222307715625*^9, 3.392223098*^9}, {3.392223139671875*^9, 
   3.392223141671875*^9}, {3.39222350825*^9, 3.392223680421875*^9}, {
   3.39222372140625*^9, 3.392223818125*^9}, {3.392223966921875*^9, 
   3.392223972640625*^9}, {3.392224197296875*^9, 3.392224218953125*^9}, {
   3.392224334796875*^9, 3.3922243526875*^9}, {3.39222464528125*^9, 
   3.392224719765625*^9}, {3.39222475246875*^9, 3.39222477453125*^9}, {
   3.39222494921875*^9, 3.392224961703125*^9}, {3.3922254010625*^9, 
   3.39222540575*^9}, {3.39222599009375*^9, 3.392226038953125*^9}, {
   3.39222615590625*^9, 3.392226162328125*^9}, {3.392226231453125*^9, 
   3.392226310453125*^9}, {3.392226377203125*^9, 3.392226381609375*^9}, {
   3.39222643528125*^9, 3.392226481890625*^9}, {3.39222710303125*^9, 
   3.39222711371875*^9}, {3.3922271855*^9, 3.3922272094375*^9}, {
   3.39230168828125*^9, 3.392301693578125*^9}, {3.392301731578125*^9, 
   3.392301740453125*^9}, {3.392302909203125*^9, 3.3923029101875*^9}, {
   3.392302957453125*^9, 3.392303012796875*^9}, 3.39230328625*^9, {
   3.392303340015625*^9, 3.392303360359375*^9}, {3.392303394546875*^9, 
   3.392303408328125*^9}, {3.392303479265625*^9, 3.3923035401875*^9}, 
   3.392303815734375*^9, {3.39230395765625*^9, 3.3923039604375*^9}, {
   3.392304000703125*^9, 3.392304040046875*^9}, {3.392304070328125*^9, 
   3.3923040746875*^9}, 3.392304137765625*^9, {3.39230434175*^9, 
   3.39230435728125*^9}, 3.39230457878125*^9, {3.392321873125*^9, 
   3.392321894078125*^9}, {3.3923220495625*^9, 3.39232208034375*^9}, {
   3.392325363875*^9, 3.39232536534375*^9}, {3.39257351521875*^9, 
   3.392573519796875*^9}, {3.39257355021875*^9, 3.3925736023125*^9}, {
   3.392573643625*^9, 3.392573644484375*^9}, {3.392574567609375*^9, 
   3.392574594953125*^9}, {3.39257464065625*^9, 3.39257467546875*^9}, {
   3.39257472925*^9, 3.39257478509375*^9}, {3.39257488346875*^9, 
   3.392574890828125*^9}, {3.392576047890625*^9, 3.39257610203125*^9}, 
   3.39257618025*^9, {3.39257646534375*^9, 3.392576466109375*^9}, {
   3.392576521609375*^9, 3.39257652828125*^9}, {3.392576570375*^9, 
   3.392576596015625*^9}, {3.392576792453125*^9, 3.39257679596875*^9}, 
   3.392577296484375*^9, {3.392577607796875*^9, 3.392577608171875*^9}, {
   3.392577748328125*^9, 3.392577748640625*^9}, 3.392577930859375*^9, {
   3.392582905484375*^9, 3.39258291478125*^9}, {3.392583076984375*^9, 
   3.392583106765625*^9}, {3.3925832094375*^9, 3.392583210015625*^9}, {
   3.392583341578125*^9, 3.392583341984375*^9}, {3.39258347690625*^9, 
   3.392583480265625*^9}, {3.392583533640625*^9, 3.392583544140625*^9}, 
   3.39258363146875*^9, {3.39258371690625*^9, 3.3925837724375*^9}, {
   3.39258382446875*^9, 3.3925838805625*^9}, {3.392583912421875*^9, 
   3.392583962609375*^9}, {3.3925840354375*^9, 3.392584044046875*^9}, {
   3.3925840839375*^9, 3.392584128890625*^9}, {3.392584346390625*^9, 
   3.39258435115625*^9}, {3.39258439475*^9, 3.392584395*^9}, 
   3.39258473715625*^9, {3.392584944859375*^9, 3.392584968328125*^9}, {
   3.392585064921875*^9, 3.392585302390625*^9}, 3.392585399875*^9, {
   3.392585573125*^9, 3.39258561196875*^9}, {3.392585654796875*^9, 
   3.39258566184375*^9}, {3.392585731609375*^9, 3.392585805671875*^9}, {
   3.39258594503125*^9, 3.392585953421875*^9}, {3.392586108984375*^9, 
   3.392586143015625*^9}, 3.39258619528125*^9, {3.392586233921875*^9, 
   3.39258623615625*^9}, {3.392586356640625*^9, 3.392586373578125*^9}, {
   3.3925866985*^9, 3.39258677196875*^9}, {3.39258686453125*^9, 
   3.392586871546875*^9}, {3.3925869628125*^9, 3.392586963109375*^9}, {
   3.39258704128125*^9, 3.392587041578125*^9}, {3.4253390909447947`*^9, 
   3.4253390959135447`*^9}, {3.4253404970229197`*^9, 
   3.4253406273041697`*^9}, {3.4253407461947947`*^9, 
   3.4253407827885447`*^9}, {3.4253410000072947`*^9, 
   3.4253410061479197`*^9}, {3.4253411135072947`*^9, 
   3.4253411149135447`*^9}, {3.4253411787572947`*^9, 
   3.4253411834291697`*^9}, {3.560299022789921*^9, 3.5602990283909283`*^9}, {
   3.5602993915944386`*^9, 3.5602994288154907`*^9}, {3.560301976569062*^9, 
   3.560301976899063*^9}, 3.560302049861165*^9, {3.5603022919495044`*^9, 
   3.5603023681716113`*^9}, {3.560302497506793*^9, 3.560302498876795*^9}, {
   3.5603025552888737`*^9, 3.5603025562788754`*^9}, {3.560306824044861*^9, 
   3.5603068243948617`*^9}, {3.5603071496153173`*^9, 
   3.5603071497053175`*^9}, {3.560307218647414*^9, 3.5603072219174185`*^9}, 
   3.56030861181137*^9, {3.5603091895511827`*^9, 3.5603091896611834`*^9}, {
   3.5603092201322255`*^9, 3.560309245013261*^9}, 3.560309333650386*^9, {
   3.5603094165635023`*^9, 3.560309417343504*^9}, {3.560309564088709*^9, 
   3.5603095644187098`*^9}, {3.560309881145155*^9, 3.560309904175187*^9}, {
   3.560338956795993*^9, 3.560338956855993*^9}, {3.560344069959484*^9, 
   3.56034407006349*^9}, {3.560345660116436*^9, 3.56034566018044*^9}, {
   3.560346690956397*^9, 3.5603466910454016`*^9}, {3.560357910447011*^9, 
   3.5603579105590177`*^9}, {3.5605566228622255`*^9, 
   3.5605567445803957`*^9}, {3.560556851723546*^9, 3.560556900674615*^9}, {
   3.5605569789507246`*^9, 3.5605569845907326`*^9}, {3.560557336779228*^9, 
   3.5605573647202673`*^9}, {3.5605574744124217`*^9, 
   3.5605574777834263`*^9}, {3.5605582510435143`*^9, 
   3.5605582725545444`*^9}, {3.560558323736616*^9, 3.5605583408576403`*^9}, {
   3.560558888661413*^9, 3.56055892907347*^9}, {3.560558998685568*^9, 
   3.5605589988055687`*^9}, {3.5631343782994213`*^9, 3.563134383809642*^9}, {
   3.5631344800154905`*^9, 3.5631344834656286`*^9}, {3.563139637869492*^9, 
   3.5631396479399953`*^9}, 3.563139723634343*^9, {3.5631397828002586`*^9, 
   3.5631397941509295`*^9}, 3.5631398543559084`*^9, {3.5631400645586348`*^9, 
   3.563140095445815*^9}, {3.5631401570339675`*^9, 3.563140170463565*^9}, {
   3.56314031128934*^9, 3.5631403199190807`*^9}, 3.5631406178774652`*^9, {
   3.563142423749855*^9, 3.5631424451752906`*^9}, {3.563147251048127*^9, 
   3.563147254598132*^9}, {3.5631473361702466`*^9, 3.5631473724712973`*^9}, {
   3.5632009021911273`*^9, 3.5632009042453327`*^9}, {3.5632012278586903`*^9, 
   3.563201230491954*^9}, {3.5632012957234764`*^9, 3.563201298475752*^9}, {
   3.5632013981697197`*^9, 3.5632013985917625`*^9}, {3.5632014308599887`*^9, 
   3.563201435960499*^9}, {3.5632021403589315`*^9, 3.5632021482507205`*^9}, {
   3.5632022743543296`*^9, 3.563202274724367*^9}, {3.5632023177456684`*^9, 
   3.5632023180647*^9}, {3.5632086095209703`*^9, 3.5632086121851006`*^9}, {
   3.563210560568533*^9, 3.5632105630286565`*^9}, {3.563296438943555*^9, 
   3.563296484165364*^9}, {3.5632965222268863`*^9, 3.56329654157766*^9}, {
   3.5632967080743203`*^9, 3.563296709984397*^9}, {3.56329675155606*^9, 
   3.56329677680707*^9}, {3.563298241531501*^9, 3.5632982416115046`*^9}, {
   3.563371146594383*^9, 3.563371150200589*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exporting the animation", "Section",
 CellChangeTimes->{{3.5607703043847284`*^9, 3.560770325165757*^9}}],

Cell["\<\
Get a list of the exported frames\
\>", "Text",
 CellChangeTimes->{{3.560770329995764*^9, 3.5607703420867815`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"frames", "=", 
   RowBox[{"FileNames", "[", "\"\<*.png\>\"", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5603368062299747`*^9, 3.5603368260530024`*^9}, 
   3.560341346719348*^9, {3.563210541687589*^9, 3.5632105424676285`*^9}}],

Cell["Re-import them", "Text",
 CellChangeTimes->{{3.560770346436787*^9, 3.5607703488267903`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"images", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Import", "[", "#", "]"}], "&"}], "/@", "frames"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.560336882726082*^9, 3.560336898316104*^9}, {
  3.560337882780484*^9, 3.5603378935404997`*^9}, {3.560342501179755*^9, 
  3.560342501698785*^9}}],

Cell["\<\
Export them to a Quicktime animation\
\>", "Text",
 CellChangeTimes->{{3.5607703535067973`*^9, 3.560770362147809*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<galaxies11.mov\>\"", ",", "images", ",", 
   RowBox[{"\"\<VideoEncoding\>\"", "\[Rule]", "\"\<MPEG-4 Video\>\""}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.560336986299227*^9, 3.5603369982702436`*^9}, 
   3.560338129569831*^9, {3.560338459920294*^9, 3.5603384600302944`*^9}, 
   3.560338765219723*^9, {3.5603413558803606`*^9, 3.5603413587803645`*^9}, {
   3.5603414404984803`*^9, 3.560341441098481*^9}, {3.5603422027096834`*^9, 
   3.5603422028296905`*^9}, 3.5603424048532457`*^9, {3.5603431747582817`*^9, 
   3.5603431748942895`*^9}, {3.5603439312495503`*^9, 3.560343931352556*^9}, {
   3.5603455514862227`*^9, 3.5603455516132298`*^9}, {3.5603497381206846`*^9, 
   3.5603497382246904`*^9}, {3.5603576361363215`*^9, 
   3.5603576366883535`*^9}, {3.560366029933419*^9, 3.5603660303414426`*^9}, {
   3.560390255180938*^9, 3.560390255460938*^9}, {3.5605620840071077`*^9, 
   3.560562084127108*^9}}],

Cell[BoxData["\<\"galaxies11.mov\"\>"], "Output",
 CellChangeTimes->{3.5605621803951073`*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1264, 787},
WindowMargins->{{Automatic, 150}, {Automatic, 5}},
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (November 20, 2012)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 91, 1, 79, "Section"],
Cell[673, 25, 629, 13, 49, "Text"],
Cell[1305, 40, 287, 5, 49, "Text"],
Cell[1595, 47, 44532, 1030, 2752, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[46164, 1082, 110, 1, 79, "Section"],
Cell[46277, 1085, 125, 3, 30, "Text"],
Cell[46405, 1090, 265, 5, 31, "Input"],
Cell[46673, 1097, 98, 1, 30, "Text"],
Cell[46774, 1100, 327, 9, 31, "Input"],
Cell[47104, 1111, 128, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[47257, 1118, 952, 15, 31, "Input"],
Cell[48212, 1135, 93, 1, 31, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
